@@ -2,11 +2,12 @@ from __future__ import annotations
 
 import os
 from collections import Counter
+from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 
 import stanza
 from stanza import Pipeline
-from tqdm.contrib.concurrent import thread_map
+from tqdm import tqdm
 
 from plagdef.model import stopwords
 from plagdef.model.models import Document, Sentence, Word
@@ -26,14 +27,14 @@ class Preprocessor:
         nlp_model = _nlp_pipe(lang)
         stop_words = stopwords.ENGLISH if lang == 'eng' else stopwords.GERMAN
         common_word_lists = _common_word_lists(nlp_model, common_docs) if common_docs else []
-        thread_map(partial(self._preprocess, nlp_model=nlp_model,
-                           common_word_lists=common_word_lists, stop_words=stop_words),
-                   docs, max_workers=os.cpu_count(), desc='Preprocessing', unit='doc')
+        with ThreadPoolExecutor(max_workers=os.cpu_count()) as p:
+            list(tqdm(p.map(partial(self._preprocess, nlp_model=nlp_model, common_word_lists=common_word_lists,
+                                    stop_words=stop_words), docs), total=len(docs), desc='Preprocessing', unit='doc'))
 
     def _preprocess(self, doc: Document, nlp_model: Pipeline, common_word_lists: list[list[str]], stop_words: set[str]):
         sents = nlp_model(doc.text).sentences
         for sent_idx, sent in enumerate(sents):
-            non_punct_words = [word for word in sent.words if not word.upos == 'PUNCT']
+            non_punct_words = [word for word in sent.words if not word.upos == 'PUNCT' and len(word.text) > 1]
             if self._rem_stop_words:
                 sent_lemmas = [word.lemma for word in non_punct_words if word.text.lower() not in stop_words]
             else:
@@ -102,8 +103,9 @@ def _common_word_lists(pipe: Pipeline, common_docs: list[Document]) -> list[list
             parsed_line = pipe(line)
             line_words = []
             for sent in parsed_line.sentences:
-                [line_words.append(word.text.lower()) for word in filter(lambda w: not w.upos == 'PUNCT', sent.words)]
-            common_word_lists.append(line_words)
+                [line_words.append(word.text.lower()) for word in filter(lambda w: not w.upos == 'PUNCT'
+                                                                                   and len(w.text) > 1, sent.words)]
+            common_word_lists.append(line_words) if len(line_words) else None
     return common_word_lists
 
 
@@ -111,7 +113,7 @@ def _to_words(stanza_tokens, sentence: Sentence) -> list[Word]:
     words = []
     for stanza_token in stanza_tokens:
         for stanza_word in stanza_token.words:
-            if not stanza_word.upos == 'PUNCT':
+            if not stanza_word.upos == 'PUNCT' and len(stanza_word.text) > 1:
                 words.append(Word(stanza_token.start_char, stanza_token.end_char, sentence))
     return words
 
